#!/usr/bin/env python3

"""Information about this version release
"""

__version__ = '1.0.0'
__title__ = 'mc-mod-getter'
__description__ = 'Easy Download & Update Mods for Minecraft'
__user__ = 'mgutierrezz'
__url__ = f'https://github.com/{__user__}/{__title__}'
__author__ = 'Michael Gutierrez'
__author_email__ = 'Michael.Gutierrez2@marist.edu'
__license__ = 'MIT'
__copyright__ = 'Copyright 2021 Michael Gutierrez'
__keywords__ = 'Package'
__project_urls__ = {
    'Bugs': f'https://github.com/{__user__}/{__title__}/issues/',
    'Documentation': f'https://github.com/{__user__}/{__title__}/',
    'Source Code': __url__,
}